@@ -3,7 +3,6 @@ require "pathname"
 require "tempfile"
 require "fileutils"
 require "stringio"
-require "webmock/rspec"
 
 RSpec.describe MiniMagick::Image do
   subject { described_class.open(image_path) }
@@ -72,41 +71,32 @@ RSpec.describe MiniMagick::Image do
     end
 
     it "loads a remote image" do
-      stub_request(:get, "http://example.com/image.jpg")
-        .to_return(body: File.read(image_path))
+      expect_any_instance_of(URI::HTTP).to receive(:open).and_yield(File.open(image_path, "rb"))
       image = described_class.open("http://example.com/image.jpg")
       expect(image).to be_valid
       expect(File.extname(image.path)).to eq ".jpg"
     end
 
-    it "doesn't allow remote shell execution" do
-      expect {
-        described_class.open("| touch file.txt") # Kernel#open accepts this
-      }.to raise_error(Errno::ENOENT)
-
-      expect(File.exist?("file.txt")).to eq(false)
-    end
-
     it "accepts open-uri options" do
-      stub_request(:get, "http://example.com/image.jpg")
-        .with(headers: {"Foo" => "Bar"})
-        .to_return(body: File.read(image_path))
-      described_class.open("http://example.com/image.jpg", {"Foo" => "Bar"})
-      described_class.open("http://example.com/image.jpg", ".jpg", {"Foo" => "Bar"})
-    end
+      expect_any_instance_of(URI::HTTP).to receive(:open)
+        .with({ "Foo" => "Bar" })
+        .and_yield(File.open(image_path, "rb"))
+      described_class.open("http://example.com/image.jpg", "Foo" => "Bar")
+    end if RUBY_VERSION >= "2.7"
+
+    it "accepts open-uri options with extension" do
+      expect_any_instance_of(URI::HTTP).to receive(:open)
+        .with({ "Foo" => "Bar" })
+        .and_yield(File.open(image_path, "rb"))
+      described_class.open("http://example.com/image.jpg", ".jpg", "Foo" => "Bar")
+    end if RUBY_VERSION >= "2.7"
 
     it "strips out colons from URL" do
-      stub_request(:get, "http://example.com/image.jpg:large")
-        .to_return(body: File.read(image_path))
+      expect_any_instance_of(URI::HTTP).to receive(:open).and_yield(File.open(image_path, "rb"))
       image = described_class.open("http://example.com/image.jpg:large")
       expect(File.extname(image.path)).to eq ".jpg"
     end
 
-    it "validates the image" do
-      expect { described_class.open(image_path(:not)) }
-        .to raise_error(MiniMagick::Invalid)
-    end
-
     it "does not mistake a path with a colon for a URI schema" do
       expect { described_class.open(image_path(:colon)) }
         .not_to raise_error
@@ -125,18 +115,6 @@ RSpec.describe MiniMagick::Image do
       expect(File.exist?(image.path)).to eq true
     end
 
-    it "validates the image if validation is set" do
-      allow(MiniMagick).to receive(:validate_on_create).and_return(true)
-      expect { create(image_path(:not)) }
-        .to raise_error(MiniMagick::Invalid)
-    end
-
-    it "doesn't validate image if validation is disabled" do
-      allow(MiniMagick).to receive(:validate_on_create).and_return(false)
-      expect { create(image_path(:not)) }
-        .not_to raise_error
-    end
-
     context "when a tmpdir is configured" do
       before { FileUtils.mkdir_p(new_tmp_dir) }
       after { FileUtils.rm_rf(new_tmp_dir) }
@@ -188,7 +166,7 @@ RSpec.describe MiniMagick::Image do
     it "is not #== nor #eql? to an instance of a different image" do
       expect(image).not_to eq(other_image)
       expect(image).not_to eql(other_image)
-    end
+    end unless Gem::Version.new(MiniMagick.cli_version) >= Gem::Version.new("7.1.1-35")
 
     it "generates the same hash code for an instance of the same image" do
       expect(image.hash).to eq(same_image.hash)
@@ -196,7 +174,7 @@ RSpec.describe MiniMagick::Image do
 
     it "generates different same hash codes for a different image" do
       expect(image.hash).not_to eq(other_image.hash)
-    end
+    end unless Gem::Version.new(MiniMagick.cli_version) >= Gem::Version.new("7.1.1-35")
   end
 
   describe "#tempfile" do
@@ -307,7 +285,7 @@ RSpec.describe MiniMagick::Image do
     end
 
     it "not change tempfile when convert failed" do
-      subject = described_class.create(nil, false) { |f| f.write(File.binread(image_path(:not))) }
+      subject = described_class.create(nil) { |f| f.write(File.binread(image_path(:not))) }
       current_path = subject.path
       new_tempfile = MiniMagick::Utilities.tempfile('png')
       new_path = new_tempfile.path
@@ -393,7 +371,6 @@ RSpec.describe MiniMagick::Image do
 
   it "has attributes" do
     expect(subject.type).to match(/^[A-Z]+$/)
-    expect(subject.mime_type).to match(/^image\/[a-z]+$/)
     expect(subject.width).to be_a(Integer).and be_nonzero
     expect(subject.height).to be_a(Integer).and be_nonzero
     expect(subject.dimensions).to all(be_a(Integer))
@@ -410,12 +387,12 @@ RSpec.describe MiniMagick::Image do
   end
 
   it "changes colorspace when called with an argument" do
-    expect_any_instance_of(MiniMagick::Tool::Mogrify).to receive(:call)
+    expect_any_instance_of(MiniMagick::Tool).to receive(:call)
     subject.colorspace("Gray")
   end
 
   it "changes size when called with an argument" do
-    expect_any_instance_of(MiniMagick::Tool::Mogrify).to receive(:call)
+    expect_any_instance_of(MiniMagick::Tool).to receive(:call)
     subject.size("20x20")
   end
 
@@ -447,55 +424,9 @@ RSpec.describe MiniMagick::Image do
     it "accepts units" do
       expect(subject.resolution("PixelsPerCentimeter"))
         .not_to eq subject.resolution("PixelsPerInch")
-    end unless ENV["GM"]
-  end
-
-  describe "#mime_type" do
-    it "returns the correct mime type" do
-      jpg = described_class.new(image_path(:jpg))
-      expect(jpg.mime_type).to eq 'image/jpeg'
     end
   end
 
-  describe "#details" do
-    it "returns a hash of verbose information" do
-      expect(subject.details["Format"]).to match /^JPEG/
-      if MiniMagick.cli.to_s.start_with?("imagemagick")
-        if MiniMagick.imagemagick7?
-          expect(subject.details["Channel depth"]["Red"]).to eq "8-bit"
-        else
-          expect(subject.details["Channel depth"]["red"]).to eq "8-bit"
-        end
-
-        expect(subject.details).to have_key("Background color")
-        expect(subject.details["Properties"]).to have_key("date:create")
-      else
-        expect(subject.details["Channel Depths"]["Red"]).to eq "8 bits"
-        expect(subject.details).to have_key("Resolution")
-      end
-    end
-
-    context "when verbose information includes an empty line" do
-      subject { described_class.new(image_path(:empty_identify_line)) }
-
-      it "skips the empty line" do
-        if MiniMagick.cli.to_s.start_with?("imagemagick")
-          expect(subject.details["Properties"]).to have_key("date:create")
-        else
-          expect(subject.details).to have_key("Date:create")
-        end
-      end
-    end
-
-    context "when verbose information includes a badly encoded line do" do
-      subject { described_class.new(image_path(:badly_encoded_line)) }
-
-      it "skips the badly encoded line" do
-        expect(subject.details).not_to have_key("Software")
-      end
-    end unless ENV["GM"]
-  end
-
   describe "#data" do
     describe "when the data return is not an array" do
       subject { described_class.new(image_path(:jpg)) }
@@ -503,7 +434,7 @@ RSpec.describe MiniMagick::Image do
       it "returns image JSON data" do
         expect(subject.data["format"]).to eq "JPEG"
         expect(subject.data["colorspace"]).to eq "sRGB"
-      end unless ENV["GM"]
+      end
     end
 
     describe "when the data return is an array (ex png)" do
@@ -512,7 +443,7 @@ RSpec.describe MiniMagick::Image do
       it "returns image JSON data" do
         expect(subject.data["format"]).to eq "PNG"
         expect(subject.data["colorspace"]).to eq "sRGB"
-      end unless ENV["GM"]
+      end
     end
   end unless ENV["CI"] # problems installing newer ImageMagick versions on CI
 
@@ -623,21 +554,18 @@ RSpec.describe MiniMagick::Image do
     end
   end
 
-  describe "missing methods" do
-    context "for a known method" do
-      it "is executed by #method_missing" do
-        expect { subject.resize '20x30!' }
-          .to change { subject.dimensions }.to [20, 30]
-      end
+  context "missing methods" do
+    it "is executed by #method_missing" do
+      expect { subject.resize '20x30!' }
+        .to change { subject.dimensions }.to [20, 30]
+    end
 
-      it "returns self" do
-        expect(subject.resize('20x30!')).to eq subject
-      end
+    it "returns self" do
+      expect(subject.resize('20x30!')).to eq subject
+    end
 
-      it "can be responded to" do
-        expect(subject.respond_to?(:gravity)).to eq true
-        expect(subject.respond_to?(:bla)).to eq false
-      end
+    it "doesn't let ruby call #to_ary when flattening" do
+      [subject, subject].flatten(1)
     end
   end
 
@@ -650,7 +578,7 @@ RSpec.describe MiniMagick::Image do
 
     it "doesn't allow calling of #format" do
       expect { subject.combine_options { |c| c.format("png") } }
-        .to raise_error(NoMethodError)
+        .to raise_error(MiniMagick::Error, "you must call #format on a MiniMagick::Image directly")
     end
 
     it "clears the info only at the end" do
@@ -679,7 +607,7 @@ RSpec.describe MiniMagick::Image do
 
     it "yields an optional block" do
       expect { |b| subject.composite(other_image, &b) }
-        .to yield_with_args(an_instance_of(MiniMagick::Tool::Composite))
+        .to yield_with_args(an_instance_of(MiniMagick::Tool))
     end
 
     it "makes the composited image with the provided extension" do
@@ -758,13 +686,6 @@ RSpec.describe MiniMagick::Image do
     end
   end
 
-  describe "#run_command" do
-    it "runs the given command" do
-      output = subject.run_command("identify", "-format", "%w", subject.path)
-      expect(output).to eq subject.width.to_s
-    end
-  end
-
   describe "#landscape?" do
     it "returns true if image width greater than height" do
       image = described_class.open(image_path(:clipping_path))
