@@ -71,7 +71,7 @@ RSpec.describe MiniMagick::Tool do
 
     it "respects #cli_prefix as an array" do
       allow(MiniMagick).to receive(:imagemagick7?).and_return(false)
-      allow(MiniMagick).to receive(:cli_prefix).and_return(['firejail', '--force'])
+      allow(MiniMagick).to receive(:cli_prefix).and_return(['firejail', '--force'].freeze)
       expect(subject.executable).to eq %W[firejail --force identify]
     end
   end
