@@ -12,8 +12,6 @@ module Helpers
         when :animation, :gif     then "animation.gif"
         when :exif                then "exif.jpg"
         when :no_exif             then "no_exif.jpg"
-        when :empty_identify_line then "empty_identify_line.png"
-        when :badly_encoded_line  then "badly_encoded_line.jpg"
         when :not                 then "not_an_image.rb"
         when :colon               then "with:colon.jpg"
         when :clipping_path       then "clipping_path.jpg"
